@@ -12,7 +12,9 @@ use Laminas\Code\Generator\MethodGenerator;
 use Laminas\Code\Generator\PromotedParameterGenerator;
 use Laminas\Code\Generator\PropertyGenerator;
 use Laminas\Code\Reflection\ClassReflection;
+use LaminasTest\Code\Generator\TestAsset\ClassWithDnfTypes;
 use LaminasTest\Code\Generator\TestAsset\ClassWithPromotedParameter;
+use LaminasTest\Code\Generator\TestAsset\ReadonlyClassWithPromotedParameter;
 use LaminasTest\Code\TestAsset\FooClass;
 use PHPUnit\Framework\TestCase;
 use ReflectionMethod;
@@ -1167,7 +1169,6 @@ class myClass
         hisTrait::foo as public test;
         myTrait::bar insteadof hisTrait;
         myTrait::bar insteadof thatTrait;
-
     }
 }
 
@@ -1187,6 +1188,24 @@ final class SomeClass
 {
 }
 
+EOS;
+
+        $output = $classGenerator->generate();
+        self::assertSame($expectedOutput, $output, $output);
+    }
+
+    public function testGenerateWithFinalReadonlyFlag(): void
+    {
+        $classGenerator = ClassGenerator::fromArray([
+            'name'  => 'SomeClass',
+            'flags' => ClassGenerator::FLAG_FINAL | ClassGenerator::FLAG_READONLY,
+        ]);
+
+        $expectedOutput = <<<EOS
+final readonly class SomeClass
+{
+}
+
 EOS;
 
         $output = $classGenerator->generate();
@@ -1396,7 +1415,7 @@ EOS;
         $expectedOutput = <<<EOS
 namespace LaminasTest\Code\Generator\TestAsset;
 
-class ClassWithPromotedParameter
+final class ClassWithPromotedParameter
 {
     public function __construct(private string \$promotedParameter)
     {
@@ -1422,4 +1441,50 @@ EOS;
             new PromotedParameterGenerator('promotedParameter', 'string'),
         ]);
     }
+
+    /** @requires PHP >= 8.2 */
+    public function testReadonlyClassWithPromotedParameterFromReflection(): void
+    {
+        $classGenerator = ClassGenerator::fromReflection(
+            new ClassReflection(ReadonlyClassWithPromotedParameter::class)
+        );
+
+        $expectedOutput = <<<EOS
+namespace LaminasTest\Code\Generator\TestAsset;
+
+final readonly class ReadonlyClassWithPromotedParameter
+{
+    public function __construct(private string \$promotedParameter)
+    {
+    }
+}
+
+EOS;
+
+        self::assertEquals($expectedOutput, $classGenerator->generate());
+    }
+
+    /** @requires PHP >= 8.2 */
+    public function testDnfClass(): void
+    {
+        $classGenerator = ClassGenerator::fromReflection(
+            new ClassReflection(ClassWithDnfTypes::class)
+        );
+
+        // @phpcs:disable Generic.Files.LineLength
+        $expectedOutput = <<<EOS
+namespace LaminasTest\Code\Generator\TestAsset;
+
+final class ClassWithDnfTypes
+{
+    public function __construct(private (\LaminasTest\Code\Generator\TestAsset\ThreeInterface&\LaminasTest\Code\Generator\TestAsset\TwoInterface)|\LaminasTest\Code\Generator\TestAsset\OneInterface \$promotedParameter)
+    {
+    }
+}
+
+EOS;
+        // @phpcs:enable
+
+        self::assertEquals($expectedOutput, $classGenerator->generate());
+    }
 }
