@@ -33,8 +33,6 @@ use function ltrim;
 use function strpos;
 use function strtolower;
 
-use const PHP_VERSION_ID;
-
 /**
  * @group Laminas_Code_Generator
  * @group Laminas_Code_Generator_Php
@@ -177,7 +175,7 @@ class ParameterGeneratorTest extends TestCase
      * @return string[][]
      * @psalm-return non-empty-list<array{non-empty-string, non-empty-string}>
      */
-    public function dataFromReflectionGenerate(): array
+    public static function dataFromReflectionGenerate(): array
     {
         return [
             ['name', '$param'],
@@ -307,7 +305,7 @@ class ParameterGeneratorTest extends TestCase
     /**
      * @return string[][]
      */
-    public function simpleHints()
+    public static function simpleHints()
     {
         return [
             ['callable', 'callable'],
@@ -349,7 +347,7 @@ class ParameterGeneratorTest extends TestCase
     /**
      * @return string[][]
      */
-    public function validClassName()
+    public static function validClassName()
     {
         return [
             ['stdClass'],
@@ -418,7 +416,7 @@ class ParameterGeneratorTest extends TestCase
     /**
      * @return string[][]
      */
-    public function reflectionHints()
+    public static function reflectionHints()
     {
         $parameters = [
             [InternalHintsClass::class, 'arrayParameter', 'foo', 'array'],
@@ -478,21 +476,13 @@ class ParameterGeneratorTest extends TestCase
             [ObjectHintsClass::class, 'nullDefaultObjectParameter', 'foo', '?object'],
         ];
 
-        $compatibleParameters = array_filter(
-            $parameters,
-            static fn(array $parameter) => PHP_VERSION_ID >= 70200
-                || (
-                    false === strpos($parameter[3], 'object')
-                )
-        );
-
         // just re-organizing the keys so that the phpunit data set makes sense in errors:
         return array_combine(
             array_map(
                 static fn(array $definition) => $definition[0] . '#' . $definition[1],
-                $compatibleParameters
+                $parameters
             ),
-            $compatibleParameters
+            $parameters
         );
     }
 
@@ -522,7 +512,7 @@ class ParameterGeneratorTest extends TestCase
     /**
      * @return string[][]
      */
-    public function variadicHints()
+    public static function variadicHints()
     {
         return [
             [VariadicParametersClass::class, 'firstVariadicParameter', 'foo', '... $foo'],
@@ -637,7 +627,7 @@ class ParameterGeneratorTest extends TestCase
     /**
      * @psalm-return non-empty-list<array{class-string, non-empty-string, positive-int|0, string, non-empty-string}>
      */
-    public function php80Methods(): array
+    public static function php80Methods(): array
     {
         return [
             [Php80Types::class, 'mixedType', 0, 'mixed', 'mixed $parameter'],
